import { I18nType } from "@/i18n/type";

export const en: I18nType = {
	dialog: {
		nextButton: "Next",
		abortButton: "Abort",
		saveButton: "Save",
		closeButton: "Close",
		moreInfoButton: "More Info",
	},
	unsupportedLocale: {
		title: "Unsupported Language",
		message:
			"Your browsers language {language} is not yet supported by this portal. You are viewing the default {defaultLanguage} version.",
		contribute: "Contribute translation",
		dontShowAgain: "Don't show again",
	},
	home: {
		title: "Certificate Portal",
		welcomeMessage: "Welcome, {name}!",
		sessionExpired: {
			moreInfo: {
				title: "Session Expiration Information",
			},
			message: "Session expired, you have been logged out.",
		},
		identificationSectionHeader: "Identification",
		requestSectionHeader: "Certificates",
		loginButton: "Login",
		logoutButton: "Logout",
		certificate: {
			button: {
				enabled: "Request",
				disabled: "In Development",
			},
			personal: {
				name: "Personal Certificate",
				description:
					"This allows you to request a personal certificate, e.g. for signing and encrypting E-Mails or signing documents. A personal certificate is bound to your person and asserted by an identification.",
			},
			function: {
				name: "Function Certificate",
				description:
					"This allows you to request a function certificate, e.g. for signing and encrypting E-Mails from a shared mailbox. No prior identification is necessary, you will just need to validate that you have control over the mail address that you want to certify.",
			},
			server: {
				name: "Server Certificate",
				description:
					"This allows you to request a server certificate necessary for secure communication between clients and servers or servers and servers. You will need to prove that you control the domain name that you want to certify.",
			},
		},
		identification: {
			button: {
				enabled: "Select",
				disabled: "In Development",
			},
			view: {
				name: "View Identification",
				description:
					"This allows you to view identifications that exist and revoke identifications that you conducted yourself in the past.",
			},
			create: {
				name: "Create Identification",
				description:
					"This allows you to create a new identification for a member of KIT. You will need to check an official document of them.",
			},
		},
	},
	createIdent: {
		title: "Create Identification",
		search: {
			header: "Search for KIT members",
			label: "Search Term",
			noResults: "No results found",
			result: {
				moreDetails: {
					kitAccountLabel: "KIT ID",
					commonNameLabel: "Common Name",
					firstNameLabel: "First Name",
					lastNameLabel: "Last Name",
					departmentLabel: "Department",
					mailAddressLabel: "E-Mail Address",
				},
				moreDetailsButton: "Details",
				identifyButton: "Identify",
			},
			rule: {
				noSpacesAllowed: "Spaces are not allowed",
				invalidKitAccount: "Invalid KIT ID format",
			},
		},
		create: {
			title: "Create identification for {name}",
			existing: {
				title: "{name} already has valid identifications",
				createdAtLabel: "Created at",
				validUntilLabel: "Valid until",
				description:
					"Please ask the KIT member if they still want to create a new identification. New identifications make sense if they recently changed their name because of a doctorate degree, wedding, transition, ...",
			},
			success: {
				title: "Successfully created new identification for {name}!",
				description: "There are now the following identifications:",
			},
			error: {
				title: "Errors occurred while creating new identification:",
			},
			documentType: {
				selectTitle: "Document Type",
				unknown: "Unknown",
				personalausweis: "Identity Card",
				passport: "Passport",
				aufenthaltstitel: "Residence Permit",
				other: "Other Document (please add remark)",
			},
			documentTypeHint:
				"For information about any document, like safety features to check, click here and search.",
			documentIdentifier: "Document Identifier (last 5 characters)",
			documentIdentifierHint: {
				title: "Information about the Document Identifier",
				text: "This picture shows where document identifiers are on the german version of the selected document. Other countries are often similar. If you can't find it, you can check the PRADO database.",
			},
			commonName: "Common Name (shown in certificates)",
			commonNameHint:
				"Currently not changeable, generated from IDM. Please compare to identity document. If there are different, cancel the identification process and redirect user to PSE for changes.",
			auditorRemarks: "Remarks",
			auditorRemarksEmptyWithDocTypeOtherError: 'Remarks can\'t be empty if document type is "Other Document"',
		},
	},
	notFound: {
		title: "404 - not found",
		message: "Page not found",
	},
	maintenance: {
		title: "Maintenance Mode",
		header: "Certificate Portal is in Maintenance Mode",
		message:
			"Certificate issuance via this portal is not ready yet. Please use the intermediary process linked below.",
		infoButton: "Intermediary Process",
	},
	errors: {
		backend: {
			title: "Critical backend error occurred",
			sorry: "This should not have happened.",
			contact: "Please contact {mail} if this issue persists.",
			requestIdHint: "Make sure to include the request ID shown below.",
		},
		requestIdLabel: "Request ID",
		unknown: "Unknown error occured.",
		backendGone: "The KIT-CA server is not reachable.",
		invalidAuthHeader: "Authentication Header was malformed.",
		invalidAuthToken: "Authentication token was invalid or expired.",
		ldapSearchSizeLimitExceeded: "Your search query lead to too many results, please specify it better.",
		problemFieldEmpty: "This field can't be empty.",
		problemFieldTooLong: "Content is too long.",
		problemFieldInvalid: "Content is invalid.",
		accountIsPseudonym:
			"The account is pseudonymous, identification does not make sense. Please tell the user to either depseudonymize the account or request a functional certificate without identification.",
	},
};
